@@ -4,7 +4,7 @@
 # --------------------------------------------------------------------------------------------
 # pylint: disable=line-too-long
 
-__version__ = "2.76.0"
+__version__ = "2.77.0"
 
 import os
 import sys
@@ -61,7 +61,7 @@ class AzCli(CLI):
         from azure.cli.core.breaking_change import register_upcoming_breaking_change_info
         from azure.cli.core.commands import register_cache_arguments
         from azure.cli.core.commands.arm import (
-            register_ids_argument, register_global_subscription_argument)
+            register_ids_argument, register_global_subscription_argument, register_global_policy_argument)
         from azure.cli.core.cloud import get_active_cloud
         from azure.cli.core.commands.transform import register_global_transforms
         from azure.cli.core._session import ACCOUNT, CONFIG, SESSION, INDEX, VERSIONS
@@ -90,6 +90,7 @@ class AzCli(CLI):
         register_global_transforms(self)
         register_global_subscription_argument(self)
         register_ids_argument(self)  # global subscription must be registered first!
+        register_global_policy_argument(self)
         register_cache_arguments(self)
         register_upcoming_breaking_change_info(self)
 
